# youtubepy
youtubepy is a package to search for youtube videos through python code.

# Usage
```python
from youtubepy import Video
video = Video("me at the zoo")
result = video.search()
print(result)
> https://youtube.com/watch/v=A8AlbaDmaec
```

Note - This package is currently under development